@@ -276,7 +276,8 @@ static const char roles[] =
   "grouping\0"
   "image map\0"
   "notification\0"
-  "info bar\0";
+  "info bar\0"
+  "level bar\0";
 
 static const guint16 roles_offsets[] = {
   0, 8, 26, 32, 42, 48, 57, 64, 
@@ -291,7 +292,7 @@ static const guint16 roles_offsets[] = {
   751, 757, 769, 782, 791, 810, 816, 822, 
   830, 845, 853, 858, 866, 883, 888, 893,
   913, 923, 933, 954, 976, 990, 1003, 1018,
-  1026, 1035, 1044, 1054, 1067
+  1026, 1035, 1044, 1054, 1067, 1075
 };
 
 /* This is a static assertion */
@@ -339,7 +340,8 @@ static void            atk_object_real_remove_property_change_handler
                                                     guint           handler_id);
 static void            atk_object_notify           (GObject         *obj,
                                                     GParamSpec      *pspec);
-
+static const gchar*    atk_object_real_get_object_locale
+                                                   (AtkObject       *object);
 
 static guint atk_object_signals[LAST_SIGNAL] = { 0, };
 
@@ -496,6 +498,7 @@ atk_object_class_init (AtkObjectClass *klass)
          atk_object_real_connect_property_change_handler;
   klass->remove_property_change_handler = 
          atk_object_real_remove_property_change_handler;
+  klass->get_object_locale = atk_object_real_get_object_locale;
 
   /*
    * We do not define default signal handlers here
@@ -1558,6 +1561,39 @@ atk_role_get_localized_name (AtkRole role)
   return atk_role_get_name (role);
 }
 
+static const gchar*
+atk_object_real_get_object_locale (AtkObject *object)
+{
+  return setlocale (LC_MESSAGES, NULL);
+}
+
+/**
+ * atk_object_get_object_locale:
+ * @accessible: an #AtkObject
+ *
+ * Gets a UTF-8 string indicating the POSIX-style LC_MESSAGES locale
+ * of @accessible.
+ *
+ * Since: 2.7.90
+ *
+ * Returns: a UTF-8 string indicating the POSIX-style LC_MESSAGES
+ *          locale of @accessible.
+ **/
+const gchar*
+atk_object_get_object_locale (AtkObject *accessible)
+{
+  AtkObjectClass *klass;
+
+  g_return_val_if_fail (ATK_IS_OBJECT (accessible), NULL);
+
+  klass = ATK_OBJECT_GET_CLASS (accessible);
+  if (klass->get_object_locale)
+    return (klass->get_object_locale) (accessible);
+  else
+    return NULL;
+}
+
+
 /**
  * atk_role_for_name:
  * @name: a string which is the (non-localized) name of an ATK role.
